<?php
/**
Plugin Name: DiscountVouchers.org Plugin
Plugin URI: http://discountvouchers.org
Description: Requires WP 2.8+
Version: 0.1
Author: http://discountvouchers.org
Author URI: http://discountvouchers.org/
*/

define('DV_SCRIPT_NAME', basename(__FILE__));
define('DV_DIR', realpath(dirname(__FILE__)));
define('DV_BASEURL', WP_PLUGIN_URL . '/'. basename(DV_DIR) . '/');

define('DV_SERVER', 'http://discountvouchers.org/');

// check wordpress version
global $wp_version;
if(version_compare($wp_version, '2.8', '<')) {
  exit('Discountvouchers plugin requires at least wordpress 2.8 or newer.'
   . '<a href="http://codex.wordpress.org/Upgrading_WordPress">Please update!<a>');
}

// plugin install
add_action('plugins_loaded', 'dv_install');
function dv_install() {
  if(!get_option('dv_text')) {
    $t = array('discount vouchers', 'discount voucher', 'discount codes', 'discount code');
    add_option('dv_text', $t[array_rand($t)]);
  }
}

// widget
add_action('widgets_init', 'dv_load_widgets');
function dv_load_widgets() {
  register_widget('DV_Widget_Category');
  register_widget('DV_Widget_Store');
}

function dv_fetch_contents($url, $options = null) {
  if(function_exists('curl_init')) {
    $ch = curl_init();
    $ua = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.0.6) Gecko/20060728 Firefox/1.5';

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_HEADER, false);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_USERAGENT, $ua);

    $data = curl_exec($ch);
    curl_close($ch);

    return $data;
  }

  return file_get_contents($url);
}

class DV_Widget_Category extends WP_Widget {

  function DV_Widget_Category() {

    $wops = array(
      'classname' => 'dv-cat',
      'description' => 'Show latest voucher codes from a category on discountvouchers.org',
      'dv-cat');

    $cops = array(
      'width' => 300,
      'height' => 350,
      'id_base' => 'dv-cat-widget');

    $this->WP_Widget('dv-cat-widget', __('Discounts by Category', 'dv-cat'), $wops, $cops);
  }

  function widget($args, $instance) {

    if($instance['only_home'] && !is_front_page()) {
      return;
    }

    extract($args);

    $title = apply_filters('widget_title', $instance['title']);

    echo $before_widget;

    if($title) echo $before_title . $title . $after_title;

    $category = explode('|', $instance['category']);
    $offers = json_decode(dv_fetch_contents($category[1] . '?only=codes&format=json'));

    if(null != $offers) {
      $sofs = array_slice($offers, 0, $instance['items']);
      foreach($sofs as $o) {
        echo "<p>{$o->title} at <a href=\"{$o->affiliate_link}\">{$o->merchant_name}</a> - voucher code <strong>{$o->code}</strong></p>\n";
      }
    }

    $apt = get_option('dv_text');

    if($instance['backlink_support']) {
      echo "<p>Latest <a href=\"{$category[1]}\">{$category[0]} {$apt}</a> provided by <a href=\"http://discountvouchers.org/\">discountvouchers.org</a>.";
    } else {
      echo "<p>Latest {$category[0]} {$apt} provided by discountvouchers.org.";
    }

    echo $after_widget;
  }

  function update($new_instance, $old_instance) {
    $instance = $old_instance;

    $instance['title'] = strip_tags($new_instance['title']);
    $instance['category'] = $new_instance['category'];
    $instance['items'] = (int) $new_instance['items'];
    $instance['only_home'] = (isset($new_instance['only_home'])) ? 1 : 0;
    $instance['backlink_support'] = (isset($new_instance['backlink_support'])) ? 1 : 0;

    return $instance;
  }

  function form($instance) {
    $cats = array();
    $js_cats = dv_fetch_contents(DV_SERVER . 'categories?format=json');

    if($js_cats) {
      $cats = json_decode($js_cats);
    }

    $defaults = array('title' => '', 'category' => '', 'items' => 2, 'only_home' => 0, 'backlink_support' => 0);
    $instance = wp_parse_args((array) $instance, $defaults);
    ?>

    <!-- title -->
    <p>
      <label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
      <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>"
        value="<?php echo $instance['title']; ?>" />
    </p>

    <!-- category -->
    <p>
      <label for="<?php echo $this->get_field_id('category'); ?>">Category:</label>
      <select class="widefat" id="<?php echo $this->get_field_id('category'); ?>" name="<?php echo $this->get_field_name('category'); ?>">
        <?php foreach($cats as $key => $val): ?>
          <?php $cval = "{$val->name}|{$val->url}"; ?>
          <option value="<?php echo $cval; ?>" <?php selected($instance['category'], $cval); ?>><?php echo $val->name; ?></option>
          <?php if(count($val->children > 0)): ?>
            <?php foreach($val->children as $k => $v): ?>
              <?php $cv = "{$v->name}|{$v->url}"; ?>
              <option value="<?php echo $cv; ?>" <?php selected($instance['category'], $cv); ?>>|-- <?php echo $v->name; ?></option>
            <?php endforeach; ?>
          <?php endif; ?>
        <?php endforeach; ?>
      </select>
    </p>

    <!-- items to display -->
    <p>
      <label for="<?php echo $this->get_field_id('items'); ?>">Items to Display:</label>
      <select id="<?php echo $this->get_field_id('items'); ?>" name="<?php echo $this->get_field_name('items'); ?>">
        <?php for($i=1; $i<=5; $i++): ?>
          <option value="<?php echo $i; ?>" <?php selected($instance['items'], $i); ?>><?php echo $i; ?></option>
        <?php endfor; ?>
      </select>
    </p>

    <!-- only home? -->
    <p>
      <input type="checkbox" id="<?php echo $this->get_field_id('only_home'); ?>" name="<?php echo $this->get_field_name('only_home'); ?>"
        value="<?php echo $instance['only_home']; ?>" <?php checked($instance['only_home'], 1); ?> />
      <label for="<?php echo $this->get_field_id('only_home'); ?>">Only Home</label>
    </p>

    <!-- backlink support? -->
    <p>
      <input type="checkbox" id="<?php echo $this->get_field_id('backlink_support'); ?>" name="<?php echo $this->get_field_name('backlink_support'); ?>"
        value="<?php echo $instance['backlink_support']; ?>" <?php checked($instance['backlink_support'], 1); ?> />
      <label style="text-wrap: on" for="<?php echo $this->get_field_id('backlink_support'); ?>">
        Support discountvouchers.org with a backlink under the discount codes list
      </label>
    </p>
    <?php
  }
}

class DV_Widget_Store extends WP_Widget {

  function DV_Widget_Store() {

    $wops = array(
      'classname' => 'dv-store',
      'description' => 'Show latest voucher codes from a specific store on discountvouchers.org',
      'dv-store');

    $cops = array(
      'width' => 300,
      'height' => 350,
      'id_base' => 'dv-store-widget');

    $this->WP_Widget('dv-store-widget', __('Discounts by Store', 'dv-store'), $wops, $cops);
  }

  function widget($args, $instance) {

    if($instance['only_home'] && !is_front_page()) {
      return;
    }

    extract($args);

    $title = apply_filters('widget_title', $instance['title']);

    echo $before_widget;

    if($title) echo $before_title . $title . $after_title;

    $store = explode('|', $instance['store']);
    $offers = json_decode(dv_fetch_contents($store[1] . '?only=codes&format=json'));

    if(null != $offers) {

      $sofs = array_slice($offers, 0, $instance['items']);
      foreach($sofs as $o) {
        echo "<p>{$o->title} at <a href=\"{$o->affiliate_link}\">{$o->merchant_name}</a> with discount voucher <strong>{$o->code}</strong></p>\n";
      }
    }

    $apt = get_option('dv_text');
    $page_title = ('' != $instance['page_title']) ? $instance['page_title'] : $store[0];

    if($instance['backlink_support']) {
      echo "<p>These <a href=\"{$store[1]}\">{$page_title} {$apt}</a> are updated automatically every day by <a href=\"http://discountvouchers.org/\">discountvouchers.org</a>.";
    } else {
      echo "<p>These {$page_title} {$apt} are updated automatically every day by discountvouchers.org.";
    }

    echo $after_widget;
  }

  function update($new_instance, $old_instance) {
    $instance = $old_instance;

    $instance['title'] = strip_tags($new_instance['title']);
    $instance['store'] = $new_instance['store'];
    $instance['items'] = (int) $new_instance['items'];
    $instance['only_home'] = (isset($new_instance['only_home'])) ? 1 : 0;
    $instance['page_title'] = strip_tags($new_instance['page_title']);
    $instance['backlink_support'] = (isset($new_instance['backlink_support'])) ? 1 : 0;

    return $instance;
  }

  function form($instance) {
    $ms = array();
    $js_ms = dv_fetch_contents(DV_SERVER . 'stores-a-z?format=json');

    if($js_ms) {
      $ms = json_decode($js_ms);
    }

    $defaults = array('title' => '', 'store' => '', 'items' => 2, 'only_home' => 0, 'page_title' => '', 'backlink_support' => 0);
    $instance = wp_parse_args((array) $instance, $defaults);
    ?>

    <!-- title -->
    <p>
      <label for="<?php echo $this->get_field_id('title'); ?>">Title:</label>
      <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>"
        value="<?php echo $instance['title']; ?>" />
    </p>

    <!-- page title -->
    <p>
      <label for="<?php echo $this->get_field_id('page_title'); ?>">Page Title:</label>
      <input class="widefat" id="<?php echo $this->get_field_id('page_title'); ?>" name="<?php echo $this->get_field_name('page_title'); ?>"
        value="<?php echo $instance['page_title']; ?>" />
    </p>

    <!-- stores -->
    <p>
      <label for="<?php echo $this->get_field_id('store'); ?>">Store:</label>
      <select class="widefat" id="<?php echo $this->get_field_id('store'); ?>" name="<?php echo $this->get_field_name('store'); ?>">
        <?php foreach($ms as $key => $val): ?>
          <optgroup style="text-align: center; text-transform: capitalize; background: #ddd; font-size: 15px;" label="<?php echo $key; ?>"><?php echo $key; ?>
            <?php foreach($val as $k => $v): ?>
              <?php $cv = "{$v->name}|{$v->full_permalink}"; ?>
              <option value="<?php echo $cv; ?>" <?php selected($instance['store'], $cv); ?>><?php echo $v->permalink; ?></option>
            <?php endforeach; ?>
          </optgroup>
        <?php endforeach; ?>
      </select>
    </p>

    <!-- items to display -->
    <p>
      <label for="<?php echo $this->get_field_id('items'); ?>">Items to Display:</label>
      <select id="<?php echo $this->get_field_id('items'); ?>" name="<?php echo $this->get_field_name('items'); ?>">
        <?php for($i=1; $i<=5; $i++): ?>
          <option value="<?php echo $i; ?>" <?php selected($instance['items'], $i); ?>><?php echo $i; ?></option>
        <?php endfor; ?>
      </select>
    </p>

    <!-- only home? -->
    <p>
      <input type="checkbox" id="<?php echo $this->get_field_id('only_home'); ?>" name="<?php echo $this->get_field_name('only_home'); ?>"
        value="<?php echo $instance['only_home']; ?>" <?php checked($instance['only_home'], 1); ?> />
      <label for="<?php echo $this->get_field_id('only_home'); ?>">Only Home</label>
    </p>

    <!-- backlink support? -->
    <p>
      <input type="checkbox" id="<?php echo $this->get_field_id('backlink_support'); ?>" name="<?php echo $this->get_field_name('backlink_support'); ?>"
        value="<?php echo $instance['backlink_support']; ?>" <?php checked($instance['backlink_support'], 1); ?> />
      <label style="text-wrap: on" for="<?php echo $this->get_field_id('backlink_support'); ?>">
        Support discountvouchers.org with a backlink under the discount codes list
      </label>
    </p>
    <?php
  }
}
